/**
 * Generates hash of given value
 */
export declare function hashCode(value: unknown): number;
/**
 * Generates v4 like [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier) (Universally unique identifier).
 *
 * > Be aware that UUID uniqueness relies heavily on the underlying random number generator (RNG).
 * > The solution above uses Math.random() for brevity, however Math.random() is not guaranteed to be a high-quality RNG.
 * > For a more robust solution, consider using the [uuid](https://github.com/uuidjs/uuid) module, which uses higher quality RNG APIs.
 *
 * @example
 * ```
 * generateUUID()
 * // '8e07ef4a-0d1f-45c2-b06b-9495e869b299'
 * ```
 **/
export declare function generateUUID(): string;
/**
 * Decodes [Base64](https://en.wikipedia.org/wiki/Base64) encoded value.
 */
export declare function base64Decode(input: string): string;
/**
 * Encodes given value with [Base64](https://en.wikipedia.org/wiki/Base64) algorithm.
 */
export declare function base64Encode(input: string): string;
