import { Primitive } from '../';
/**
 * Generates cookie string
 *
 * @example
 * ```
 * // Create a cookie, valid across the entire site:
 * document.cookie = generateCookie('name', 'value')
 *
 * // Create a cookie that expires 7 days from now, valid across the entire site:
 * document.cookie = generateCookie('name', 'value', { expires: 7 })
 * ```
 * @param name cookie name
 * @param value cookie value
 */
export declare function generateCookie(name: string, value: string, options?: {
    /**
     * Expire cookie after x days (negative to remove cookie)
     */
    expires?: number;
}): string;
/**
 * Parses cookies string
 *
 * @example
 * ```
 * parseCookies(document.cookie)
 * // {session: '26e761be168533cbf0742f8c295176c7'}
 * ```
 * @group Http
 * @param cookieString `document.cookie` value
 */
export declare function parseCookies(cookieString: string): Record<string, string>;
/**
 * Parse a query string given as a string argument.
 *
 * @example
 * ```
 * location.search
 * // ?page=1&limit=20
 *
 * parseQueryString(location.search)
 * // { page: ['1'], limit: ['20']}
 * ```
 * @group Http
 */
export declare function parseQueryString(query: string, options?: {
    /**
     * @default `&`
     */
    separator?: string;
}): Record<string, string[]>;
/**
 * Generates query string form provided object.
 *
 * @example
 * ```
 * generateQueryString({ page: 1, limit: 20})
 * // 'page=1&limit=20'
 * ```
 * @group Http
 * @param query
 * @param options
 * @returns
 */
export declare function generateQueryString(query: Record<string, Primitive[] | Primitive>, options?: {
    /**
     * @default `&`
     */
    separator?: string;
}): string;
/**
 * Converts absolute URL to relative
 *
 * @example
 * ```
 * urlToRelative('https://domain.com/index.html')
 * // /index.html
 * ```
 */
export declare function urlToRelative(url: string): string;
