/**
 * Returns a random integer between min (inclusive) and max (inclusive).
 *
 * @example
 * ```
 * randomInt(1, 10)
 * // 9
 * ```
 * @group Random
 */
export declare function randomInt(min: number, max: number): number;
/**
 * Returns a random element from the array or `undefined` if the array is empty.
 *
 * @example
 * ```
 * randomChoice([1, 2, 3, 4, 5])
 * // 2
 * ```
 * @group Random
 */
export declare function randomChoice<T>(array: ReadonlyArray<T>): T | undefined;
/**
 * Generate new array by randomly picking items from provided array
 *
 * @example
 * ```
 * randomChoices([1, 2], 3)
 * // [2, 2, 1]
 * ```
 * @group Random
 */
export declare function randomChoices<T>(array: ReadonlyArray<T>, length: number): T[];
/**
 * Generates random string between min (inclusive) and max (inclusive) length.
 *
 * By default it uses [[asciiLetters]] + [[digits]] + [[punctuation]]
 *
 * @param length
 * @param options
 * @returns
 */
export declare function randomString(length: number, options?: {
    chars?: string;
}): string;
/**
 * Shuffles the the array.
 *
 * @example
 * ```
 * shuffle([1, 2, 3])
 * // [2, 1, 3]
 * ```
 * @group Random
 */
export declare function shuffle<T>(array: ReadonlyArray<T>): ReadonlyArray<T>;
export declare function shuffle<T>(array: T[]): T[];
