/**
 * The lowercase letters `abcdefghijklmnopqrstuvwxyz`.
 *
 * @group String
 */
export declare const asciiLowercase = "abcdefghijklmnopqrstuvwxyz";
/**
 * The uppercase letters `ABCDEFGHIJKLMNOPQRSTUVWXYZ`.
 *
 * @group String
 */
export declare const asciiUppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
/**
 * The concatenation of the [[asciiLowercase]] and [[asciiUppercase]] constants.
 *
 * @group String
 */
export declare const asciiLetters: string;
/**
 * The string `0123456789`.
 *
 * @group String
 */
export declare const digits = "0123456789";
/**
 * The string `0123456789abcdefABCDEF`.
 *
 * @group String
 */
export declare const hexdigits = "0123456789abcdefABCDEF";
/**
 * The string `01234567`.
 *
 * @group String
 */
export declare const octdigits = "01234567";
/**
 * String of ASCII characters which are considered punctuation characters in the C locale:
 * `!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~.`
 *
 * @group String
 */
export declare const punctuation = "!\"#$%&'()*+,-./:;<=>?@[]^_`{|}~";
/**
 * Check if given value contains at least one letter.
 *
 * @example
 * ```
 * isLetter('a')
 * // true
 * isLetter('-')
 * // false
 * ```
 * @group String
 */
export declare function isLetter(value: string): boolean;
/**
 * Truncates string
 *
 * @example
 * ```
 * truncate('Hello world', 8)
 * // Hello...
 * ```
 * @group String
 */
export declare function truncate(value: string, length: number, ending?: string): string;
/**
 * Extract words from text.
 *
 * @example
 * ```
 * extractWords('Hello-world!')
 * // ['Hello', 'world']
 * ```
 * @group String
 */
export declare function extractWords(value: string): string[];
/**
 * Convert a dash/dot/underscore/space separated string to camelCase
 *
 * @example
 * ```
 * camelCase('foo-bar');
 * // 'fooBar'
 * ```
 * @group String
 */
export declare function camelCase(value: string): string;
/**
 * Convert a dash/dot/underscore/space separated string to PascalCase
 *
 * @example
 * ```
 * pascalCase('foo-bar');
 * // 'FooBar'
 * ```
 * @group String
 */
export declare function pascalCase(value: string): string;
/**
 * Convert the first letter in each to word upper case
 *
 * @example
 * ```
 * titleCase('hello world');
 * // 'Hello World'
 * ```
 * @group String
 */
export declare function titleCase(value: string): string;
